Altre finestre — SoL 3, manuale utente

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »

# Altre finestre

L’orologio con allarme.

## Orologio

Il semplice orologio analogico è basato su CoolClock e su SoundManager per poter ottenere un allarme sonoro.

Il conto alla rovescia può essere attivato sia con un doppio click sull’orologio oppure usando il primo pulsante in basso; un altro modo di farlo è usando il secondo pulsante che farà partire il tempo dopo 15 secondi, dando così modo all’operatore di raggiungere il proprio tavolo di gioco.

L’orologio utilizza i valori impostati in durata e preavviso sul torneo per disegnare tre cerchietti colorati in verde, arancio e rosso, a rappresentare rispettivamente il minuto di partenza, quello di preavviso e quello di conclusione del turno. Se si sta utilizzando un moderno browser HTML5, oppure se si è installato correttamente il plugin Flash, l’orologio emette un breve suono.

Al raggiungimento del preavviso apparirà la lancetta dei secondi e viene emesso un suono differente: in genere questo significa che, mancando pochi minuti al termine, non possono essere iniziate nuove partite, mentre quelle in corso possono terminare.

A un minuto dal termine l’orologio emette un tic-tac ad ogni secondo. Alla fine, raggiunto il punto rosso, viene emesso il suono di termine: a quel punto le partite ancora in corso devono essere fermate e il punteggio verrà determinato dalla sola differenza pedine ancora in gioco, senza tener conto della Regina.

Chiudere la finestra con l’orologio (o usa il terzo pulsante in basso) per annullare l’allarme.

Importante

L’allarme viene reimpostato ad ogni doppio click: pur essendo utile in caso di una falsa partenza, è un po’ delicato. Si raccomanda di tenere un secondo orologio indipendente dal computer.

Caricamento dati torneo.

## Caricamento

Con questa semplice finestra è possibile caricare i dati di un intero torneo, provenienti da un’altra istanza di SoL. I nuovi dati non sovrascriveranno quelli esistenti, delle entità preesistenti verranno aggiornati solo i dati mancanti.

Chiunque può caricare archivi `.sol` (o la versione compressa `.sol.gz`). Gli utenti autenticati, tranne l’utente guest, possono caricare anche archivi `.zip` con i dati dei tornei insieme ai ritratti dei giocatori e agli stemmi dei club.

Esportazione dei dati

I dati dei tornei possono essere estratti con il pulsante Scarica nelle gestioni dei tornei e dei campionati: si tratta di file di testo, in formato YAML (eventualmente compresso), che possono essere ricaricati in un’altra istanza di SoL, piuttosto che archiviati per sicurezza. L’archivio creato in questo modo contiene tutti i tornei specificati così come i dati relativi a tutti i giocatori, club e campionati coinvolti. Non contiene nessuna immagine, né ritratti né stemmi.

Un altro modo consente di esportare l’intero database, cioè tutti i tornei e tutti i giocatori (indipendentemente se abbiano partecipato a un torneo o meno) e tutte le immagini associate. Visitando l’indirizzo:

    http://localhost:6996/bio/backup

si otterrà un archivio `ZIP` contenente tutto quanto, che potrà essere caricato in un’altra installazione di SoL, copiando/aggiornando così praticamente tutte le informazioni memorizzate e le relative immagini. Chiaramente l’archivio prodotto in questo modo avrà dimensioni molto maggiori del precedente: questo metodo è raccomandato solo per migrare l’intero database a una nuova versione di SoL, oppure qualora si desideri copiare tutte le immagini in un colpo solo.

### Navigazione

- indice
- successivo |
- precedente |
- Manuale d'uso »
- Interfaccia utente »